@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10194 2017-08-16 05:53:21Z David $
+# $Id: __init__.py 10321 2017-09-26 09:03:30Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-08-16 13:53:21 +0800 (週三, 16 八月 2017) $
-# $Revision: 10194 $
+# $Date: 2017-09-26 17:03:30 +0800 (Tue, 26 Sep 2017) $
+# $Revision: 10321 $
 
 import os
 import sys
@@ -287,23 +287,20 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     
     import socket
     
-    if settingsDict['SERVER_MODE'] == DEVELOPMENT:
-        ALLOWED_HOSTS = [
-            'localhost', 
-            '127.0.0.1',
-            '::1', 
-            # 1.8.16 required for stage server. See:
-            # https://docs.djangoproject.com/en/1.10/releases/
-            # 1.8.16/#dns-rebinding-vulnerability-when-debug-true
-            '.nuwainfo.com', 
-            '.tracedig.com',
-            '.%s' % '.'.join(socket.gethostname().split('.')[1:]),
-        ]
-    else:
-        ALLOWED_HOSTS = ['127.0.0.1', 'localhost']
-    
+    ALLOWED_HOSTS = [
+        'localhost', 
+        '127.0.0.1',
+        '::1', 
+        # 1.8.16 required for stage server. See:
+        # https://docs.djangoproject.com/en/1.10/releases/
+        # 1.8.16/#dns-rebinding-vulnerability-when-debug-true
+        '.nuwainfo.com', 
+        '.tracedig.com',
+        '.%s' % '.'.join(socket.gethostname().split('.')[1:]),
+    ]
+
     defaultAllowedDomains = {
-        'ALLOWED_DOMAINS': ['127.0.0.1', 'localhost']
+        'ALLOWED_DOMAINS': []
     }
 
     if settingsDict.get('ALLOWED_DOMAINS', None):
