@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Nuwa.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: Nuwa.py 10419 2017-10-29 15:30:56Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: Kevin $ (last)
+# $Date: 2017-10-29 23:30:56 +0800 (Sun, 29 Oct 2017) $
+# $Revision: 10419 $
 
 from Iuno.cloud.backend import BaseBackend
 from Iuno.cloud.logging.backend import BackendMixin
@@ -27,10 +27,9 @@ class Backend(BaseBackend, BackendMixin):
     SENTRY_CONFIGS = {
         'sentry.nuwainfo.com': {
             'test': {
-                'SENTRY_DSN': ('threaded+https://'
-                    '419b30ac13704aabb4efaacfa99c5736:'
-                    '301644578dc44afaaef54940223686f8@'
-                    'sentry.nuwainfo.com/3?timeout=60'),
+                'SENTRY_DSN': ('https://28dd3e48e1f144e6b595d120e331662e:'
+                               'dbeda9f0462945938ce908b1727a7323@'
+                               'sentry.nuwainfo.com/8'),
             },
             'mail': {
                 'SENTRY_DSN': ('threaded+https://'
