@@ -113,7 +113,7 @@ class Command(BaseCommand):
         # Footer
         temp = get_template('scaffold/FooterTemplate.py')
         footer = temp.render()
-        content = content + footer
+        content = content.strip() + '\n' + footer
 
         with open(settingPath, 'wb') as setting:
             setting.write(content.replace('\r\n', '\n'))
